pub struct Invdata {
pub forcenumcmp: bool,
pub cleansign: bool,
}Expand description
INVDATA: zoned and packed items may hold invalid digits, sign codes or zone bits. FORCENUMCMP compares zoned items as numbers whatever their zones; CLEANSIGN cleans a sign code on input to a comparison or computation (Programming Guide SC27-8714-03, pp. 376-378). ZONEDATA(NOPFD) and ZONEDATA(MIG) are INVDATA with FORCENUMCMP off and on.
Fields
forcenumcmp: boolcleansign: boolTrait Implementations
impl Copy for Invdata
impl Eq for Invdata
impl StructuralPartialEq for Invdata